@@ -5,6 +5,8 @@ Author: Alex Braun
 Email: Alexander.G.Braun@gmail.com
 Github: https://github.com/theNewFlesh
 '''
+from lunchbox import command  # noqa F401
 from lunchbox import enforce  # noqa F401
+from lunchbox import singleton  # noqa F401
 from lunchbox import stopwatch  # noqa F401
 from lunchbox import tools  # noqa F401
