@@ -199,8 +199,10 @@ def truncate_blob_lists(blob, size=3):
 
 
 # LOGGING-----------------------------------------------------------------------
-def log_runtime(function, *args, message_=None, _testing=False, **kwargs):
-    # type (Callable, ..., Optional[str], bool, ...) -> Any
+def log_runtime(
+    function, *args, message_=None, _testing=False, log_level='info', **kwargs
+):
+    # type (Callable, ..., Optional[str], bool, str, ...) -> Any
     r'''
     Logs the duration of given function called with given arguments.
 
@@ -209,11 +211,17 @@ def log_runtime(function, *args, message_=None, _testing=False, **kwargs):
         \*args (object, optional): Arguments.
         message_ (str, optional): Message to be returned. Default: None.
         _testing (bool, optional): Returns message if True. Default: False.
+        log_level (str, optional): Log level. Default: info.
         \*\*kwargs (object, optional): Keyword arguments.
 
+    Raises:
+        EnforceError: If log level is illegal.
+
     Returns:
         object: function(*args, **kwargs).
     '''
+    level = log_level_to_int(log_level)
+
     # this may silently break file writes in multiprocessing
     stopwatch = StopWatch()
     stopwatch.start()
@@ -231,7 +239,7 @@ def log_runtime(function, *args, message_=None, _testing=False, **kwargs):
     if _testing:
         return message_
 
-    LOGGER.info(message_)
+    LOGGER.log(level, message_)
     return output
 
 
@@ -254,6 +262,44 @@ def runtime(wrapped, instance, args, kwargs):
     return log_runtime(wrapped, *args, **kwargs)
 
 
+def log_level_to_int(level):
+    # type: (Union[str, int]) -> int
+    '''
+    Convert a given string or integer into a log level integer.
+
+    Args:
+        level (str or int): Log level.
+
+    Raises:
+        EnforceError: If level is illegal.
+
+    Returns:
+        int: Log level as integer.
+    '''
+    keys = ['critical', 'debug', 'error', 'fatal', 'info', 'warn', 'warning']
+    values = [getattr(logging, x.upper()) for x in keys]
+    lut = dict(zip(keys, values))  # type: Dict[str, int]
+
+    msg = 'Log level must be an integer or string. Given value: {a}. '
+    lut_msg = ', '.join([f'{k}: {v}' for k, v in zip(keys, values)])
+    msg += f'Legal values: [{lut_msg}].'
+
+    output = 0
+    if isinstance(level, int):
+        Enforce(level, 'in', values, message=msg)
+        output = level
+
+    elif isinstance(level, str):
+        level = level.lower()
+        Enforce(level, 'in', keys, message=msg)
+        output = lut[level]
+
+    else:
+        raise EnforceError(msg.format(a=level))
+
+    return output
+
+
 class LogRuntime:
     '''
     LogRuntime is a class for logging the runtime of arbitrary code.
@@ -279,9 +325,15 @@ class LogRuntime:
         Fooing all the bars - Runtime: 0:00:01.001069 (1 second)
     '''
     def __init__(
-        self, message='', name='LogRuntime', level='info', suppress=False
+        self,
+        message='',  # type: str
+        name='LogRuntime',  # type: str
+        level='info',  # type: str
+        suppress=False,  # type: bool
+        message_func=None,  # type: Optional[Callable[[str, StopWatch], None]]
+        callback=None,  # type: Optional[Callable[[str], Any]]
     ):
-        # type: (str, str, Union[str, int], bool) -> None
+        # type: (...) -> None
         '''
         Constructs a LogRuntime instance.
 
@@ -291,6 +343,10 @@ class LogRuntime:
             level (str or int, optional): Log level. Default: info.
             suppress (bool, optional): Whether to suppress logging.
                 Default: False.
+            message_func (function, optional): Custom message function of the
+                signature (message, StopWatch) -> str. Default: None.
+            callback (function, optional): Callback function of the signature
+                (message) -> Any. Default: None.
 
         Raises:
             EnforceError: If message is not a string.
@@ -301,33 +357,42 @@ class LogRuntime:
         Enforce(message, 'instance of', str)
         Enforce(name, 'instance of', str)
         Enforce(suppress, 'instance of', bool)
-
-        keys = ['debug', 'info', 'warn', 'error', 'critical', 'fatal']
-        values = [getattr(logging, x.upper()) for x in keys]
-        lut = dict(zip(keys, values))  # type: Dict[str, int]
-
-        msg = 'Log level must be an integer or string. Given value: {a}. '
-        lut_msg = ', '.join([f'{k}: {v}' for k, v in zip(keys, values)])
-        msg += f'Legal values: [{lut_msg}].'
-
-        level_ = 0
-        if isinstance(level, int):
-            Enforce(level, 'in', values, message=msg)
-
-        elif isinstance(level, str):
-            level = level.lower()
-            Enforce(level, 'in', keys, message=msg)
-            level_ = lut[level]
-
-        else:
-            raise EnforceError(msg.format(a=level))
         # ----------------------------------------------------------------------
 
         self._message = message
         self._stopwatch = StopWatch()
         self._logger = logging.getLogger(name)
-        self._level = level_
+        self._level = log_level_to_int(level)
         self._suppress = suppress
+        self._message_func = message_func
+        self._callback = callback
+
+    @staticmethod
+    def _default_message_func(message, stopwatch):
+        # type: (str, StopWatch) -> str
+        '''
+        Add runtime information to message given StopWatch instance.
+
+        Args:
+            message (str): Message.
+            stopwatch (StopWatch): StopWatch instance.
+
+        Raises:
+            EnforeceError: If Message is not a string.
+            EnforceError: If stopwatch is not a StopWatch instance.
+
+        Returns:
+            str: Message with runtime information.
+        '''
+        Enforce(message, 'instance of', str)
+        Enforce(stopwatch, 'instance of', StopWatch)
+        # ----------------------------------------------------------------------
+
+        msg = f'Runtime: {stopwatch.delta} '
+        msg += f'({stopwatch.human_readable_delta})'
+        if message != '':
+            msg = message + ' - ' + msg
+        return msg
 
     def __enter__(self):
         # type: () -> LogRuntime
@@ -345,19 +410,19 @@ class LogRuntime:
         '''
         Stops stopwatch and logs message.
         '''
-        self._stopwatch.stop()
-
-        msg = f'Runtime: {self._stopwatch.delta} '
-        msg += f'({self._stopwatch.human_readable_delta})'
-        if self._message != '':
-            msg = self._message + ' - ' + msg
-        self.message = msg
-
+        stopwatch = self._stopwatch
+        stopwatch.stop()
         self.delta = self._stopwatch.delta
         self.human_readable_delta = self._stopwatch.human_readable_delta
 
+        msg_func = self._message_func or self._default_message_func
+        self.message = msg_func(self._message, stopwatch)
+
         if not self._suppress:
-            self._logger.log(self._level, msg)
+            self._logger.log(self._level, self.message)
+
+        if self._callback is not None:
+            self._callback(str(self.message))
 
 
 # HTTP-REQUESTS-----------------------------------------------------------------
